==> libgtop-1.0.6.tgz: etc/libgtopConf.sh <==
#
# Configuration of the libgtop package
#

LIBGTOP_LIBDIR="/usr/local/etc"
LIBGTOP_INCLUDEDIR="/usr/local/include"

LIBGTOP_DATADIR="/usr/local/share"

LIBGTOP_EXTRA_LIBS="-L/usr/X11R6/lib -lXau -L/usr/local/lib -lglib12"

LIBGTOP_LIBS="-L/usr/local/lib -lgtop -lgtop_sysdeps -lgtop_common"
LIBGTOP_INCS="-I/usr/local/include -DHAVE_GLIBTOP_MACHINE_H -I/usr/X11R6/include -DNEED_GNOMESUPPORT_H -I/usr/local/include/glib12 -I/usr/local/include -I/usr/X11R6/include/gtk12 -I/usr/local/include/glib12"

LIBGTOP_NAMES_LIBS="-L/usr/local/lib -lgtop -lgtop_sysdeps -lgtop_common -lgtop_names"
LIBGTOP_NAMES_INCS="-I/usr/local/include -DHAVE_GLIBTOP_MACHINE_H -I/usr/X11R6/include -DNEED_GNOMESUPPORT_H -I/usr/local/include/glib12 -I/usr/local/include -I/usr/X11R6/include/gtk12 -I/usr/local/include/glib12 -DGLIBTOP_NAMES"

LIBGTOP_GUILE_LIBS="-L/usr/local/lib -lgtop_guile -lgtop -lgtop_sysdeps -lgtop_common -L/usr/local/lib -lguile -lm"
LIBGTOP_GUILE_INCS="-I/usr/local/include -DHAVE_GLIBTOP_MACHINE_H -I/usr/X11R6/include -DNEED_GNOMESUPPORT_H -I/usr/local/include/glib12 -I/usr/local/include -I/usr/X11R6/include/gtk12 -I/usr/local/include/glib12 -I/usr/local/include -DGLIBTOP_GUILE"

LIBGTOP_GUILE_NAMES_LIBS="-L/usr/local/lib -lgtop_guile -lgtop -lgtop_sysdeps -lgtop_common -lgtop_guile_names -lgtop_names"
LIBGTOP_GUILE_NAMES_INCS="-I/usr/local/include -DHAVE_GLIBTOP_MACHINE_H -I/usr/X11R6/include -DNEED_GNOMESUPPORT_H -I/usr/local/include/glib12 -I/usr/local/include -I/usr/X11R6/include/gtk12 -I/usr/local/include/glib12 -I/usr/local/include -DGLIBTOP_GUILE -DGLIBTOP_NAMES"

LIBGTOP_BINDIR="/usr/local/bin"
LIBGTOP_SERVER="/usr/local/bin/libgtop_server"

LIBGTOP_MAJOR_VERSION="1"
LIBGTOP_MINOR_VERSION="0"
LIBGTOP_MICRO_VERSION="6"

LIBGTOP_VERSION="1.0.6"
LIBGTOP_VERSION_CODE="1000006"

MODULE_VERSION="libgtop-1.0.6"

LIBGTOP_SERVER_VERSION="5"

libgtop_sysdeps_dir="freebsd"
libgtop_need_server="yes"
libgtop_use_machine_h="yes"

libgtop_guile_found="yes"

libgtop_want_examples=""

==> libgtop-1.0.9.tgz: etc/libgtopConf.sh <==
#
# Configuration of the libgtop package
#

LIBGTOP_LIBDIR="/usr/local/etc"
LIBGTOP_INCLUDEDIR="/usr/local/include"

LIBGTOP_DATADIR="/usr/local/share/gnome"

LIBGTOP_EXTRA_LIBS="-L/usr/X11R6/lib -lXau -L/usr/local/lib -lglib12"

LIBGTOP_LIBS="-L/usr/local/lib -lgtop -lgtop_sysdeps -lgtop_common"
LIBGTOP_INCS="-I/usr/local/include -DHAVE_GLIBTOP_MACHINE_H -I/usr/X11R6/include -DNEED_GNOMESUPPORT_H -I/usr/local/include/glib12 -I/usr/local/include -I/usr/X11R6/include/gtk12 -I/usr/local/include/glib12"

LIBGTOP_NAMES_LIBS="-L/usr/local/lib -lgtop -lgtop_sysdeps -lgtop_common -lgtop_names"
LIBGTOP_NAMES_INCS="-I/usr/local/include -DHAVE_GLIBTOP_MACHINE_H -I/usr/X11R6/include -DNEED_GNOMESUPPORT_H -I/usr/local/include/glib12 -I/usr/local/include -I/usr/X11R6/include/gtk12 -I/usr/local/include/glib12 -DGLIBTOP_NAMES"

LIBGTOP_GUILE_LIBS="-L/usr/local/lib -lgtop_guile -lgtop -lgtop_sysdeps -lgtop_common -L/usr/local/lib -lguile -lqthreads -lm"
LIBGTOP_GUILE_INCS="-I/usr/local/include -DHAVE_GLIBTOP_MACHINE_H -I/usr/X11R6/include -DNEED_GNOMESUPPORT_H -I/usr/local/include/glib12 -I/usr/local/include -I/usr/X11R6/include/gtk12 -I/usr/local/include/glib12 -I/usr/local/include -DGLIBTOP_GUILE"

LIBGTOP_GUILE_NAMES_LIBS="-L/usr/local/lib -lgtop_guile -lgtop -lgtop_sysdeps -lgtop_common -lgtop_guile_names -lgtop_names"
LIBGTOP_GUILE_NAMES_INCS="-I/usr/local/include -DHAVE_GLIBTOP_MACHINE_H -I/usr/X11R6/include -DNEED_GNOMESUPPORT_H -I/usr/local/include/glib12 -I/usr/local/include -I/usr/X11R6/include/gtk12 -I/usr/local/include/glib12 -I/usr/local/include -DGLIBTOP_GUILE -DGLIBTOP_NAMES"

LIBGTOP_BINDIR="/usr/local/bin"
LIBGTOP_SERVER="/usr/local/bin/libgtop_server"

LIBGTOP_MAJOR_VERSION="1"
LIBGTOP_MINOR_VERSION="0"
LIBGTOP_MICRO_VERSION="9"

LIBGTOP_VERSION="1.0.9"
LIBGTOP_VERSION_CODE="1000009"

MODULE_VERSION="libgtop-1.0.9"

LIBGTOP_SERVER_VERSION="5"

libgtop_sysdeps_dir="freebsd"
libgtop_need_server="yes"
libgtop_use_machine_h="yes"

libgtop_guile_found="yes"

libgtop_want_examples=""
